@@ -1,5 +1,5 @@
 package SVN::Dump::Reader;
-$SVN::Dump::Reader::VERSION = '0.07';
+$SVN::Dump::Reader::VERSION = '0.08';
 use strict;
 use warnings;
 use IO::Handle;
@@ -25,7 +25,7 @@ my @digest = grep {
 sub new {
     my ($class, $fh, $args) = @_;
     croak 'SVN::Dump::Reader parameter is not a filehandle'
-        if !( $fh && ref $fh && ref($fh) eq 'GLOB' );
+      unless eval { $fh && ref $fh && $fh->can('getline') && $fh->can('read') };
     %{*$fh} = %{ $args || {} };
     return bless $fh, $class;
 }
@@ -210,7 +210,7 @@ SVN::Dump::Reader - A Subversion dump reader
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
